@@ -1,6 +1,6 @@
 package Ubic::Watchdog;
 {
-  $Ubic::Watchdog::VERSION = '1.53';
+  $Ubic::Watchdog::VERSION = '1.54';
 }
 
 use strict;
@@ -137,12 +137,19 @@ sub check($) {
             return;
         }
 
+        my $cached_status = Ubic->cached_status($name);
         my $status = Ubic->status($name);
         unless ($status->status eq 'running') {
             # following code can throw an exception, so we want to cache invalid status immediately
             Ubic->set_cached_status($name, $status);
 
-            ERROR("$name status is '$status', restarting");
+            if ($cached_status eq "autostarting") {
+                INFO("$name is autostarting");
+            }
+            else {
+                ERROR("$name status is '$status', restarting");
+            }
+
             Ubic->restart($name);
 
             # This is a precaution against services with wrong start/status logic.
@@ -175,7 +182,7 @@ Ubic::Watchdog - watchdog code
 
 =head1 VERSION
 
-version 1.53
+version 1.54
 
 =head1 SYNOPSIS
 
